@@ -19,12 +19,14 @@ It is used via a single directive in the .rst file
 
 """
 
+from os import path
 import re
 
 from docutils import nodes
 from docutils.parsers import rst
 import six
 from six.moves import configparser
+from sphinx.util.fileutil import copy_asset
 
 KEY_PATTERN = re.compile("[^a-zA-Z0-9_]")
 DRIVER_PREFIX = "driver."
@@ -73,7 +75,7 @@ class Matrix(object):
             if cfg.has_option(section, "status"):
                 # The value is a string "status(group)" where
                 # the 'group' part is optional
-                status, group = re.match('^([^(]+)(?:\(([^)]+)\))?$',
+                status, group = re.match(r'^([^(]+)(?:\(([^)]+)\))?$',
                                          cfg.get(section, "status")).groups()
 
                 if status not in Feature.STATUS_ALL:
@@ -87,10 +89,16 @@ class Matrix(object):
             if cfg.has_option(section, "cli"):
                 cli = cfg.get(section, "cli")
 
+            api = None
+            if cfg.has_option(section, "api"):
+                api = cfg.get(section, "api")
+
             notes = None
             if cfg.has_option(section, "notes"):
                 notes = cfg.get(section, "notes")
-            return Feature(section, title, status, group, notes, cli)
+            return Feature(
+                section, title,
+                status=status, group=group, notes=notes, cli=cli, api=api)
 
         def _process_implementation(section, option, feature):
             if option not in self.drivers:
@@ -248,7 +256,7 @@ class Directive(rst.Directive):
         """
 
         summary_title = nodes.subtitle(text="Summary")
-        summary = nodes.table()
+        summary = nodes.table(classes=["sp_feature_cells"])
         cols = len(matrix.drivers.keys())
 
         # Add two columns for the Feature and Status columns.
@@ -269,10 +277,10 @@ class Directive(rst.Directive):
         # This sets up all the column headers - two fixed
         # columns for feature name & status
         header = nodes.row()
-        blank = nodes.entry()
+        blank = nodes.entry(classes=["sp_feature_cells"])
         blank.append(nodes.emphasis(text="Feature"))
         header.append(blank)
-        blank = nodes.entry()
+        blank = nodes.entry(classes=["sp_feature_cells"])
         blank.append(nodes.emphasis(text="Status"))
         header.append(blank)
         summary_head.append(header)
@@ -282,9 +290,17 @@ class Directive(rst.Directive):
                        key=lambda x: matrix.drivers[x].title)
         for key in impls:
             driver = matrix.drivers[key]
-            implcol = nodes.entry()
+            implcol = nodes.entry(classes=["sp_feature_cells"])
             header.append(implcol)
-            implcol.append(nodes.strong(text=driver.title))
+            if driver.link:
+                uri = driver.link
+                target_ref = nodes.reference("", refuri=uri)
+                target_txt = nodes.inline()
+                implcol.append(target_txt)
+                target_txt.append(target_ref)
+                target_ref.append(nodes.strong(text=driver.title))
+            else:
+                implcol.append(nodes.strong(text=driver.title))
 
         # We now produce the body of the table, one row for
         # each feature to report on
@@ -295,7 +311,7 @@ class Directive(rst.Directive):
             feature_id = re.sub(KEY_PATTERN, "_", feature.key)
 
             # first the fixed columns for title/status
-            key_col = nodes.entry()
+            key_col = nodes.entry(classes=["sp_feature_cells"])
             item.append(key_col)
             key_ref = nodes.reference(refid=feature_id)
             key_txt = nodes.inline()
@@ -303,7 +319,7 @@ class Directive(rst.Directive):
             key_txt.append(key_ref)
             key_ref.append(nodes.strong(text=feature.title))
 
-            status_col = nodes.entry()
+            status_col = nodes.entry(classes=["sp_feature_cells"])
             item.append(status_col)
             status_col.append(nodes.inline(
                 text=feature.status,
@@ -312,7 +328,7 @@ class Directive(rst.Directive):
             # and then one column for each backend driver
             for key in impls:
                 impl = feature.implementations[key]
-                impl_col = nodes.entry()
+                impl_col = nodes.entry(classes=["sp_feature_cells"])
                 item.append(impl_col)
 
                 key_id = re.sub(KEY_PATTERN, "_",
@@ -463,6 +479,15 @@ class Directive(rst.Directive):
         return para
 
 
+def on_build_finished(app, exc):
+    if exc is None:
+        src = path.join(path.abspath(path.dirname(__file__)),
+                        'support-matrix.css')
+        dst = path.join(app.outdir, '_static')
+        copy_asset(src, dst)
+
+
 def setup(app):
     app.add_directive('support_matrix', Directive)
-    app.add_stylesheet('support-matrix.css')
+    app.add_css_file('support-matrix.css')
+    app.connect('build-finished', on_build_finished)
